nbxmpp.dispatcher_nb

Package nbxmpp :: Module dispatcher_nb |
[hide private]
[frames] | no frames]

# Module dispatcher_nb

source code

Main xmpp decision making logic. Provides library with methods to assign different handlers to different XMPP stanzas and namespaces

Classes | [hide private]
| Dispatcher Why is this here - I needed to redefine Dispatcher for BOSH and easiest way was to inherit original Dispatcher (now renamed to XMPPDispatcher). Trouble is that reference used to access dispatcher instance is in Client attribute named by __class__.__name__ of the dispatcher instance .. long story short:
| XMPPDispatcher Handles XMPP stream and is the first who takes control over a fresh stanza
| BOSHDispatcher

Variables | [hide private]
| log = `logging.getLogger('nbxmpp.dispatcher_nb')`
| DEFAULT_TIMEOUT_SECONDS = `25` default timeout to wait for response for our id
| outgoingID = `0`
| XML_DECLARATION = ``'``<?xml version=\'1.0\'?>``'``
| __package__ = ``'``nbxmpp``'``

Imports: simplexml, sys, locale, re, ExpatError, PlugIn, NS_STREAMS, NS_XMPP_STREAMS, NS_HTTP_BIND, Iq, Presence, Message, Protocol, Node, Error, ERR_FEATURE_NOT_IMPLEMENTED, StreamError, logging

Variables Details | [hide private]

  ### log Value:
      logging.getLogger('nbxmpp.dispatcher_nb')

  ### DEFAULT_TIMEOUT_SECONDS default timeout to wait for response for our id Value:
      25

  ### outgoingID Value:
      0

  ### XML_DECLARATION Value:
      '<?xml version=\'1.0\'?>'

  ### __package__ Value:
      'nbxmpp'